@@ -19,11 +19,11 @@ Audit::DBI - Audit data changes in your code and store searchable log records in
 
 =head1 VERSION
 
-Version 1.7.1
+Version 1.7.2
 
 =cut
 
-our $VERSION = '1.7.1';
+our $VERSION = '1.7.2';
 
 
 =head1 SYNOPSIS
@@ -649,7 +649,7 @@ sub review ## no critic (Subroutines::ProhibitExcessComplexity)
 		{
 			my $clause = '(name = ' . $dbh->quote( lc( $value->{'name'} ) ) . ')';
 			
-			$clause = "($clause AND (value IN (" . join( ',', map { $dbh->quote( lc( $value ) ) } @{ $value->{'values'} } ) . ')))'
+			$clause = "($clause AND (value IN (" . join( ',', map { $dbh->quote( lc( $_ ) ) } @{ $value->{'values'} } ) . ')))'
 				if defined( $value->{'values'} ) && ( scalar( @{ $value->{'values'} } ) != 0 );
 			
 			$clause = "(NOT $clause)"
